from KalturaClient import *
from KalturaClient.Plugins.Core import *
from KalturaClient.Plugins.Caption import *

import hashlib

def createKalturaSession():
    # get following information from cast-support@switch.ch
    partner_id=partnerNumber
    id=anID
    token=aTokenNumber
    userId=aUserId

    config = KalturaConfiguration(partner_id)
    config.serviceUrl = "https://api.cast.switch.ch/"
    client = KalturaClient(config)

    # generate a widget session in order to use the app token
    widgetId = "_"+str(partner_id)
    expiry = 86400

    result = client.session.startWidgetSession(widgetId, expiry)
    client.setKs(result.ks)
    tokenHash = hashlib.sha256(result.ks.encode('ascii')+token.encode('ascii')).hexdigest()
    type = KalturaSessionType.ADMIN

    # start an app token session
    session = client.appToken.startSession(id, tokenHash, userId, type, expiry);
    client.setKs(session.ks)
    return client

def get_userID(client, email):
    # see https://developer.kaltura.com/api-docs/service/user/action/list for
    # additional filters and pager setings
    filter = KalturaUserFilter()
    filter.emailLike = email
    pager = None
    result = client.user.list(filter, pager)
    if result.objects:
        return result.objects[0].id
    else:
        return ''

def get_channel_list(client, userID):
    # see https://developer.kaltura.com/api-docs/service/category/action/list for
    # additional filters and pager setings
    filter = KalturaCategoryFilter()
    filter.managerEqual = userID
    pager = KalturaFilterPager()
    result = client.category.list(filter, pager)
    if result.objects:
        for each in result.objects:
            print(str(each.id)+' - '+each.name)

def get_media(client, cat_ID):
    # see https://developer.kaltura.com/api-docs/service/media/action/list for
    # additional filters and pager setings
    filter = KalturaMediaEntryFilter()
    filter.categoriesIdsMatchAnd = cat_ID
    pager = KalturaFilterPager()
    result = client.media.list(filter, pager)
    if result.objects:
        for each in result.objects:
            print(str(each.id)+' - '+each.name)

def delete_video(client, video_ID):
    # see https://developer.kaltura.com/api-docs/service/media/action/list for
    # additional filters and pager setings
    filter = KalturaMediaEntryFilter()
    filter.id = video_ID
    pager = None
    result = client.media.list(filter, pager)
    # if video exist, delete it
    if result.objects:
        entry_id = result.objects[0].id
        client.media.delete(entry_id)

def upload_video(client, info_Dict):
    # see https://developer.kaltura.com/api-docs/service/uploadToken
    # and https://developer.kaltura.com/api-docs/service/media for
    # additional information about uploading video

    # create uploadToken
    upload_token = KalturaUploadToken()
    upload_token = client.uploadToken.add(upload_token)

    # upload file
    filename = info_Dict["file"]
    file_data = open(filename, 'rb')
    resume = False
    final_chunk = True
    resume_at = -1
    try:
        client.uploadToken.upload(upload_token.id, file_data, resume, final_chunk, resume_at)
    except Exception as e:
        print(e)

    owner = info_Dict["owner"]

    # add media entry
    entry = KalturaMediaEntry()
    entry.mediaType = KalturaMediaType.VIDEO
    entry.name = info_Dict["title"]
    entry.userId = owner
    entry.categoriesIds = info_Dict["channel_ID"]
    entry.mediaType = 1   # 1=video, 5=audio
    entry = client.media.add(entry)

    # attach media to entry
    resource = KalturaUploadedFileTokenResource(upload_token.id)
    client.media.addContent(entry.id, resource)

def upload_Caption(media_id, caption_dict):
    # see https://developer.kaltura.com/api-docs/service/captionAsset for
    # additional information to upload captions
    #test if cation already exist
    filter = KalturaAssetFilter()
    filter.entryIdEqual = media_id
    pager = None
    result = client.caption.captionAsset.list(filter, pager)
    if len(result.objects) > 0:
        for each in result.objects:
        #     client.caption.captionAsset.delete(each.id)
        #     return
            language_code = caption_dict['language'].split('-')[0]
            if language_code in ['bs','sc']:
                label = language_code
            else:
                label = getattr(KalturaLanguage, language_code.upper())
            if each.label == label:
                return
    # create uploadToken
    upload_token = KalturaUploadToken()
    upload_token = client.uploadToken.add(upload_token)

    # upload file
    filename = caption_dict['filename']
    file_data = open(filename, 'rb')
    resume = False
    final_chunk = True
    resume_at = -1
    try:
        client.uploadToken.upload(upload_token.id, file_data, resume, final_chunk, resume_at)
    except Exception as e:
        print(e)

    # create caption asset
    entryId = media_id
    captionAsset = KalturaCaptionAsset()
    language_code = caption_dict['language'].split('-')[0]
    if language_code in ['bs', 'sc']:
        captionAsset.label = language_code
    else:
        captionAsset.label = getattr(KalturaLanguage, language_code.upper())
        captionAsset.language = getattr(KalturaLanguage, language_code.upper())
        captionAsset.languageCode = language_code
    captionAsset.format = KalturaCaptionType.SRT  #'1' _< SRT, '3' -> WEBVTT, etc
    result = client.caption.captionAsset.add(entryId, captionAsset)

    # attach media to entry
    resource = KalturaUploadedFileTokenResource(upload_token.id)

    client.caption.captionAsset.setContent(result.id, resource)


def getDowloadURLsOfDualVideo(entryID):
    # prints out  urls to download for parent and child
    client = createKalturaSession()
    # get downloadURL form parent
    try:
        parent = client.baseEntry.get(entryID, None)
    except:
        print("This media {} does not exist".format(entryID))
        return
    print('Parent: {}'.format(parent.downloadUrl))
    filter = KalturaBaseEntryFilter()
    filter.parentEntryIdEqual = entryID
    child = client.baseEntry.list(filter, None)
    if not child.objects:
        print("This media {} does not contain a child".format(entryID))
        return
    print('Child: {}'.format(child.objects[0].downloadUrl))


if __name__ == '__main__':
    client = createKalturaSession()
    # get user id
#    user_ID = get_userID(client, 'markus.buerer@switch.ch')
    # get a list of channels (called categories in kaltura)
#    get_channel_list(client, user_ID)
    # get all videos to a specific channel/categorie
#    get_media(client, 24994)
    # delete a video
#    delete_video(client, '0_0xaimvx3')
    # upload video
#    info_Dict = {"file": "/Users/buerer/Movies/examples/Wasserall.mp4",
#                 "title": "WasserFall 2",
#                 "channel_ID": 24994,
#                 "owner": user_ID}
#    upload_video(client, info_Dict)
    # get downloadable URLS of parent-child
#    getDowloadURLsOfDualVideo('0_fpxxiy0q')
    # upload caption e.g. .vtt file
    # dict = {'filename':'/Users/buerer/Downloads/Example/caption-fr.srt', 'language':'fr-fr'}
    # upload_Caption('0_er4m2s0e', dict)
